<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr_FR">
<context>
    <name>QObject</name>
    <message>
        <location filename="../qsynthSetup.cpp" line="37"/>
        <source>(default)</source>
        <translation>(défaut)</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="224"/>
        <source>Usage: %1 [options] [soundfonts] [midifiles]</source>
        <translation>Utilisation : %1 [options] [banquedesons] [fichiersmidi]</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="227"/>
        <source>Options</source>
        <translation>Options</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="229"/>
        <location filename="../qsynthOptions.cpp" line="285"/>
        <source>Don&apos;t create a midi driver to read MIDI input events [default = yes]</source>
        <translation>Ne pas créer un pilote midi pour lire les évènements d&apos;entrée MIDI [défaut = oui]</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="231"/>
        <location filename="../qsynthOptions.cpp" line="287"/>
        <source>The name of the midi driver to use [oss,alsa,alsa_seq,...]</source>
        <translation>Le nom du pilote MIDI à utiliser [oss,alsa,alsa_esq,...]</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="233"/>
        <location filename="../qsynthOptions.cpp" line="289"/>
        <source>The number of midi channels [default = 16]</source>
        <translation>Le nombre de canaux MIDI [défaut = 16]</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="235"/>
        <location filename="../qsynthOptions.cpp" line="291"/>
        <source>The audio driver [alsa,jack,oss,dsound,...]</source>
        <translation>Le pilote audio [alsa,jack,oss,dsound,...]</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="237"/>
        <location filename="../qsynthOptions.cpp" line="293"/>
        <source>Attempt to connect the jack outputs to the physical ports</source>
        <translation>Tentative de connecter les sorties JACK aux ports physiques</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="239"/>
        <location filename="../qsynthOptions.cpp" line="295"/>
        <source>The number of stereo audio channels [default = 1]</source>
        <translation>Le nombre de canaux audio stéréo [défaut = 1]</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="241"/>
        <location filename="../qsynthOptions.cpp" line="297"/>
        <source>The number of audio groups [default = 1]</source>
        <translation>Le nombre de groupes audio [défaut = 1]</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="243"/>
        <location filename="../qsynthOptions.cpp" line="299"/>
        <source>Size of each audio buffer</source>
        <translation>Taille de chaque tampon audio</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="245"/>
        <location filename="../qsynthOptions.cpp" line="301"/>
        <source>Number of audio buffers</source>
        <translation>Nombre de tampons audio</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="247"/>
        <location filename="../qsynthOptions.cpp" line="303"/>
        <source>Set the sample rate</source>
        <translation>Défini la fréquence d&apos;échantillonnage</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="249"/>
        <location filename="../qsynthOptions.cpp" line="305"/>
        <source>Turn the reverb on or off [1|0|yes|no|on|off, default = on]</source>
        <translation>Allume ou éteind la réverbération [1|0|yes|no|on|off, défaut = on]</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="251"/>
        <location filename="../qsynthOptions.cpp" line="307"/>
        <source>Turn the chorus on or off [1|0|yes|no|on|off, default = on]</source>
        <translation>Allume ou éteind le chorus [1|0|yes|no|on|yes, défaut = on]</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="253"/>
        <location filename="../qsynthOptions.cpp" line="309"/>
        <source>Set the master gain [0 &lt; gain &lt; 2, default = 1]</source>
        <translation>Défini le gain général [0 &lt; gain &lt; 2, défaut = 1]</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="255"/>
        <location filename="../qsynthOptions.cpp" line="311"/>
        <source>Define a setting name=value</source>
        <translation>Défini un paramètre nom=valeur</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="257"/>
        <location filename="../qsynthOptions.cpp" line="313"/>
        <source>Create and start server [default = no]</source>
        <translation>Crée et démarre un serveur [défaut = no]</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="259"/>
        <location filename="../qsynthOptions.cpp" line="315"/>
        <source>Don&apos;t read commands from the shell [ignored]</source>
        <translation>Ne pas lire les commandes à partir de la console [ignoré]</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="261"/>
        <location filename="../qsynthOptions.cpp" line="317"/>
        <source>Dump midi router events</source>
        <translation>Affiche les évènements du routeur MIDI</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="263"/>
        <location filename="../qsynthOptions.cpp" line="319"/>
        <source>Print out verbose messages about midi events</source>
        <translation>Affiche les messages détaillés concernant les évènements MIDI</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="265"/>
        <source>Show help about command line options</source>
        <translation>Affiche l&apos;aide à propos des options de ligne de commande</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="267"/>
        <source>Show version information</source>
        <translation>Affiche les informations de version</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="323"/>
        <source>SoundFont Files</source>
        <translation>Fichiers de banque de sons</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="324"/>
        <source>[soundfonts]</source>
        <translation>[banque de sons]</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="326"/>
        <source>MIDI Files</source>
        <translation>Fichiers MIDI</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="327"/>
        <source>[midifiles]</source>
        <translation>[fichiersmidi]</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="337"/>
        <location filename="../qsynthOptions.cpp" line="513"/>
        <source>Option -m requires an argument (midi-driver).</source>
        <translation>L&apos;option -m requiert un argument (pilote-midi).</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="347"/>
        <location filename="../qsynthOptions.cpp" line="522"/>
        <source>Option -K requires an argument (midi-channels).</source>
        <translation>L&apos;option -K requiert un argument (canaux-midi).</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="356"/>
        <location filename="../qsynthOptions.cpp" line="531"/>
        <source>Option -a requires an argument (audio-driver).</source>
        <translation>L&apos;option -a requiert un argument (pilote-audio).</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="370"/>
        <location filename="../qsynthOptions.cpp" line="543"/>
        <source>Option -L requires an argument (audio-channels).</source>
        <translation>L&apos;option -L requiert un argument (canaux-audio).</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="380"/>
        <location filename="../qsynthOptions.cpp" line="552"/>
        <source>Option -G requires an argument (audio-groups).</source>
        <translation>L&apos;option -G requiert un argument (groupes-audio).</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="390"/>
        <location filename="../qsynthOptions.cpp" line="561"/>
        <source>Option -z requires an argument (audio-bufsize).</source>
        <translation>L&apos;option -z requiert un argument (taille-tampon-audio).</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="400"/>
        <location filename="../qsynthOptions.cpp" line="570"/>
        <source>Option -c requires an argument (audio-bufcount).</source>
        <translation>L&apos;option -c requiert un argument (compte-tampon-audio).</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="410"/>
        <location filename="../qsynthOptions.cpp" line="579"/>
        <source>Option -r requires an argument (sample-rate).</source>
        <translation>L&apos;option -r requiert un argument (taux-échantillonnage).</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="438"/>
        <location filename="../qsynthOptions.cpp" line="606"/>
        <source>Option -g requires an argument (gain).</source>
        <translation>L&apos;option -g requiert un argument (gain).</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="447"/>
        <location filename="../qsynthOptions.cpp" line="615"/>
        <source>Option -o requires an argument.</source>
        <translation>L&apos;option -o requiert un argument.</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="482"/>
        <location filename="../qsynthOptions.cpp" line="664"/>
        <source>Unknown option &apos;%1&apos;.</source>
        <translation>Option &apos;%1&apos; inconnue.</translation>
    </message>
</context>
<context>
    <name>qsynthAboutForm</name>
    <message>
        <location filename="../qsynthAboutForm.ui" line="33"/>
        <source>About</source>
        <translation>À propos</translation>
    </message>
    <message>
        <location filename="../qsynthAboutForm.ui" line="64"/>
        <source>&amp;Close</source>
        <translation>&amp;Fermer</translation>
    </message>
    <message>
        <location filename="../qsynthAboutForm.ui" line="74"/>
        <source>About Qt</source>
        <translation>À propos de Qt</translation>
    </message>
    <message>
        <location filename="../qsynthAboutForm.cpp" line="64"/>
        <source>Version</source>
        <translation>Version</translation>
    </message>
    <message>
        <location filename="../qsynthAboutForm.cpp" line="45"/>
        <source>Debugging option enabled.</source>
        <translation>Option de débogage activée.</translation>
    </message>
    <message>
        <location filename="../qsynthAboutForm.cpp" line="48"/>
        <source>System tray disabled.</source>
        <translation>Barre d&apos;état desactivée.</translation>
    </message>
    <message>
        <location filename="../qsynthAboutForm.cpp" line="51"/>
        <source>Server option disabled.</source>
        <translation>Option du serveur désactivée.</translation>
    </message>
    <message>
        <location filename="../qsynthAboutForm.cpp" line="54"/>
        <source>System reset option disabled.</source>
        <translation>Option de remise à zéro du système désactivée.</translation>
    </message>
    <message>
        <location filename="../qsynthAboutForm.cpp" line="57"/>
        <source>Bank offset option disabled.</source>
        <translation>Option de décalage de banque désactivée.</translation>
    </message>
    <message>
        <location filename="../qsynthAboutForm.cpp" line="72"/>
        <source>Using: Qt %1</source>
        <translation>Utilisant : Qt %1</translation>
    </message>
    <message>
        <location filename="../qsynthAboutForm.cpp" line="78"/>
        <source>FluidSynth %1</source>
        <translation>FluidSynth %1</translation>
    </message>
    <message>
        <location filename="../qsynthAboutForm.cpp" line="82"/>
        <source>Website</source>
        <translation>Site web</translation>
    </message>
    <message>
        <location filename="../qsynthAboutForm.cpp" line="87"/>
        <source>This program is free software; you can redistribute it and/or modify it</source>
        <translation>Ce programme est un programme libre; vous pouvez le redistribuer et/ou le modifier</translation>
    </message>
    <message>
        <location filename="../qsynthAboutForm.cpp" line="88"/>
        <source>under the terms of the GNU General Public License version 2 or later.</source>
        <translation>sous les termes de la license publique générale GNU version 2 ou plus récente.</translation>
    </message>
</context>
<context>
    <name>qsynthChannelsForm</name>
    <message>
        <location filename="../qsynthChannelsForm.ui" line="59"/>
        <source>Preset &amp;Name:</source>
        <translation>&amp;Nom du pré-réglage :</translation>
    </message>
    <message>
        <location filename="../qsynthChannelsForm.ui" line="80"/>
        <source>Settings preset name</source>
        <translation>Définir le nom de pré-réglage</translation>
    </message>
    <message>
        <location filename="../qsynthChannelsForm.ui" line="87"/>
        <source>(default)</source>
        <translation>(défaut)</translation>
    </message>
    <message>
        <location filename="../qsynthChannelsForm.ui" line="95"/>
        <source>Save settings as current preset name</source>
        <translation>Sauvegarder les réglages sous le nom courant de pré-réglage</translation>
    </message>
    <message>
        <location filename="../qsynthChannelsForm.ui" line="98"/>
        <source>&amp;Save</source>
        <translation>&amp;Sauvegarder</translation>
    </message>
    <message>
        <location filename="../qsynthChannelsForm.ui" line="111"/>
        <source>Delete current settings preset</source>
        <translation>Supprimer les paramètres actuels prédéfinis</translation>
    </message>
    <message>
        <location filename="../qsynthChannelsForm.ui" line="114"/>
        <source>&amp;Delete</source>
        <translation>&amp;Supprimer</translation>
    </message>
    <message>
        <location filename="../qsynthChannelsForm.ui" line="146"/>
        <source>Channels view</source>
        <translation>Vue des canaux</translation>
    </message>
    <message>
        <location filename="../qsynthChannelsForm.ui" line="171"/>
        <source>In</source>
        <translation>Entrée</translation>
    </message>
    <message>
        <location filename="../qsynthChannelsForm.ui" line="176"/>
        <source>Chan</source>
        <translation>Canal</translation>
    </message>
    <message>
        <location filename="../qsynthChannelsForm.ui" line="181"/>
        <source>Bank</source>
        <translation>Banque</translation>
    </message>
    <message>
        <location filename="../qsynthChannelsForm.ui" line="186"/>
        <source>Prog</source>
        <translation>Prog</translation>
    </message>
    <message>
        <location filename="../qsynthChannelsForm.ui" line="191"/>
        <source>Name</source>
        <translation>Nom</translation>
    </message>
    <message>
        <location filename="../qsynthChannelsForm.ui" line="196"/>
        <source>SFID</source>
        <translation>SFID</translation>
    </message>
    <message>
        <location filename="../qsynthChannelsForm.ui" line="201"/>
        <source>Soundfont</source>
        <translation>Banque de son</translation>
    </message>
    <message>
        <location filename="../qsynthChannelsForm.ui" line="36"/>
        <source>Channels</source>
        <translation>Canaux</translation>
    </message>
    <message>
        <location filename="../qsynthChannelsForm.cpp" line="355"/>
        <source>Edit</source>
        <translation>Éditer</translation>
    </message>
    <message>
        <location filename="../qsynthChannelsForm.cpp" line="360"/>
        <source>Unset</source>
        <translation>Désactiver</translation>
    </message>
    <message>
        <location filename="../qsynthChannelsForm.cpp" line="364"/>
        <source>Refresh</source>
        <translation>Rafraichir</translation>
    </message>
    <message>
        <location filename="../qsynthChannelsForm.cpp" line="492"/>
        <source>Warning</source>
        <translation>Attention</translation>
    </message>
    <message>
        <location filename="../qsynthChannelsForm.cpp" line="493"/>
        <source>Delete preset:</source>
        <translation>Supprimer le pré-réglage :</translation>
    </message>
    <message>
        <location filename="../qsynthChannelsForm.cpp" line="495"/>
        <source>Are you sure?</source>
        <translation>Êtes-vous sûr ?</translation>
    </message>
</context>
<context>
    <name>qsynthMainForm</name>
    <message>
        <location filename="../qsynthMainForm.ui" line="46"/>
        <source>Master</source>
        <translation>Général</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="64"/>
        <source>&amp;Gain</source>
        <translation>&amp;Volume</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="86"/>
        <location filename="../qsynthMainForm.ui" line="111"/>
        <source>Master Gain</source>
        <translation>Volume Général</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="127"/>
        <source>Complete engine restart</source>
        <translation>Redémarrage complet du moteur</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="130"/>
        <location filename="../qsynthMainForm.cpp" line="1385"/>
        <location filename="../qsynthMainForm.cpp" line="1480"/>
        <source>Re&amp;start</source>
        <translation>R&amp;edémarrage</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="146"/>
        <source>Reverb</source>
        <translation>Réverbération</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="170"/>
        <source>Reverb effect activation</source>
        <translation>Activation de l&apos;effet de réverbération</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="173"/>
        <source>Ac&amp;tive</source>
        <translation>Ac&amp;tiver</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="186"/>
        <location filename="../qsynthMainForm.ui" line="205"/>
        <source>Reverb Level</source>
        <translation>Niveau de réverbération</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="230"/>
        <source>&amp;Level</source>
        <translation>&amp;Niveau</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="252"/>
        <location filename="../qsynthMainForm.ui" line="293"/>
        <source>Reverb Width</source>
        <translation>Largeur de réverbération</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="271"/>
        <source>&amp;Width</source>
        <translation>&amp;Largeur</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="318"/>
        <location filename="../qsynthMainForm.ui" line="359"/>
        <source>Reverb Damp Factor</source>
        <translation>Facteur d&apos;atténuation de la réverbération</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="337"/>
        <source>D&amp;amp</source>
        <translation>&amp;Atténuation</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="384"/>
        <location filename="../qsynthMainForm.ui" line="425"/>
        <source>Reverb Room Size</source>
        <translation>Dimension de la pièce de réverbération</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="403"/>
        <source>R&amp;oom</source>
        <translation>P&amp;ièce</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="453"/>
        <source>Chorus</source>
        <translation>Chorus</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="477"/>
        <source>Chorus Modulation Type</source>
        <translation>Type de modulation de chorus</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="481"/>
        <source>Sine</source>
        <translation>Sinus</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="486"/>
        <source>Triangle</source>
        <translation>Triangle</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="506"/>
        <source>T&amp;ype:</source>
        <translation>T&amp;ype :</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="534"/>
        <source>Chorus effect activation</source>
        <translation>Activation de l&apos;effet chorus</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="537"/>
        <source>Act&amp;ive</source>
        <translation>Act&amp;iver</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="550"/>
        <location filename="../qsynthMainForm.ui" line="597"/>
        <source>Number of Chorus Stages</source>
        <translation>Nombre d&apos;Etages de Chorus</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="575"/>
        <source>&amp;N</source>
        <translation>&amp;N</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="616"/>
        <location filename="../qsynthMainForm.ui" line="663"/>
        <source>Chorus Level</source>
        <translation>Niveau de Chorus</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="641"/>
        <source>Le&amp;vel</source>
        <translation>Ni&amp;veau</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="682"/>
        <location filename="../qsynthMainForm.ui" line="735"/>
        <source>Chorus Speed (Hz)</source>
        <translation>Vitesse du Chorus (Hz)</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="710"/>
        <source>Chorus Speed Hz</source>
        <translation>Vitesse du Chorus Hz</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="713"/>
        <source>Spee&amp;d</source>
        <translation>Vi&amp;tesse</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="757"/>
        <location filename="../qsynthMainForm.ui" line="804"/>
        <source>Chorus Depth (ms)</source>
        <translation>Profondeur du Chorus (ms)</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="782"/>
        <source>Dept&amp;h</source>
        <translation>Profon&amp;deur</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="829"/>
        <source>Output peak level</source>
        <translation>Niveau de sortie crête</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="847"/>
        <source>Quit this application</source>
        <translation>Quitter cette application</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="850"/>
        <location filename="../qsynthMainForm.cpp" line="1432"/>
        <source>&amp;Quit</source>
        <translation>&amp;Quitter</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="863"/>
        <source>Show general options dialog</source>
        <translation>Afficher la fenêtre de dialogue des options générales</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="866"/>
        <location filename="../qsynthMainForm.cpp" line="1426"/>
        <source>&amp;Options...</source>
        <translation>&amp;Options...</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="879"/>
        <source>Show/hide the messages log window</source>
        <translation>Afficher/cacher la fenêtre de log des messages</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="882"/>
        <location filename="../qsynthMainForm.cpp" line="1422"/>
        <source>&amp;Messages</source>
        <translation>&amp;Messages</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="898"/>
        <source>Show information about this application</source>
        <translation>Afficher les informations à propos de cette application</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="901"/>
        <source>A&amp;bout...</source>
        <translation>À &amp;propos...</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="932"/>
        <source>System reset</source>
        <translation>Remise à zéro du système</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="935"/>
        <location filename="../qsynthMainForm.cpp" line="1390"/>
        <source>&amp;Panic</source>
        <translation>&amp;Panique</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="945"/>
        <source>Program reset (all channels)</source>
        <translation>Remise à zéro du programme (tous les canaux)</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="948"/>
        <location filename="../qsynthMainForm.cpp" line="1387"/>
        <source>&amp;Reset</source>
        <translation>&amp;Remise à zéro</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="958"/>
        <source>Show instance settings and configuration dialog</source>
        <translation>Afficher la fenêtre de réglage et de configuration de l&apos;instance</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="961"/>
        <location filename="../qsynthMainForm.cpp" line="1399"/>
        <location filename="../qsynthMainForm.cpp" line="1872"/>
        <source>Set&amp;up...</source>
        <translation>Config&amp;uration...</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="974"/>
        <source>Show/hide the channels view window</source>
        <translation>Afficher/cacher la fenêtre de vue des canaux</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="977"/>
        <location filename="../qsynthMainForm.cpp" line="1394"/>
        <source>&amp;Channels</source>
        <translation>&amp;Canaux</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="1016"/>
        <source>Add a new engine</source>
        <translation>Ajouter un nouveau moteur</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="1029"/>
        <source>Engine selector (right-click for menu)</source>
        <translation>Sélectionneur de moteur (clic droit pour le menu)</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="1067"/>
        <source>Delete current engine</source>
        <translation>Supprimer le moteur courant</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="856"/>
        <source>Information</source>
        <translation>Information</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="858"/>
        <source>The program will keep running in the system tray.

To terminate the program, please choose &quot;Quit&quot;
in the context menu of the system tray icon.</source>
        <translation>Le programme continuera de s&apos;exécuter dans la barre d&apos;état du système.

Pour terminer ce programme, veuillez choisir &quot;Quitter&quot;
dans le menu contextuel de l&apos;icône de la barre d&apos;état du système.</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="874"/>
        <source>Don&apos;t show this message again</source>
        <translation>Ne pas montrer ce message à nouveau</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="899"/>
        <location filename="../qsynthMainForm.cpp" line="1609"/>
        <location filename="../qsynthMainForm.cpp" line="2358"/>
        <location filename="../qsynthMainForm.cpp" line="2388"/>
        <source>Warning</source>
        <translation>Attention</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="901"/>
        <source>is about to terminate.</source>
        <translation>est sur le point de terminer.</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="902"/>
        <location filename="../qsynthMainForm.cpp" line="1612"/>
        <source>Are you sure?</source>
        <translation>Êtes-vous sûr ?</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="912"/>
        <source>Don&apos;t ask this again</source>
        <translation>Ne pas le redemander</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="1010"/>
        <source>Loading soundfont: &quot;%1&quot;</source>
        <translation>Charge la banque de son : &quot;%1&quot;</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="1021"/>
        <location filename="../qsynthMainForm.cpp" line="2048"/>
        <source>Failed to load the soundfont: &quot;%1&quot;.</source>
        <translation>Échec du chargement de la banque de son : &quot;%1&quot;.</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="1048"/>
        <source>Playing MIDI file: &quot;%1&quot;</source>
        <translation>Joue le fichier MIDI : &quot;%1&quot;</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="1055"/>
        <source>Failed to play MIDI file: &quot;%1&quot;.</source>
        <translation>N&apos;a pas pu jouer le fichier MIDI : &quot;%1&quot;.</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="1260"/>
        <source>Error</source>
        <translation>Erreur</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="1368"/>
        <source>&amp;Hide</source>
        <translation>&amp;Cacher</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="1364"/>
        <source>Mi&amp;nimize</source>
        <translation>&amp;Minimiser</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="1369"/>
        <source>S&amp;how</source>
        <translation>Affic&amp;her</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="1365"/>
        <source>Rest&amp;ore</source>
        <translation>Restaurati&amp;on</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="1377"/>
        <location filename="../qsynthMainForm.cpp" line="1866"/>
        <source>&amp;New engine...</source>
        <translation>&amp;Nouveau moteur...</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="1379"/>
        <location filename="../qsynthMainForm.cpp" line="1868"/>
        <source>&amp;Delete</source>
        <translation>&amp;Supprimer</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="1385"/>
        <location filename="../qsynthMainForm.cpp" line="1482"/>
        <source>&amp;Start</source>
        <translation>&amp;Démarrer</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="1405"/>
        <source>Engines</source>
        <translation>Moteurs</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="1610"/>
        <source>Delete fluidsynth engine:</source>
        <translation>Supprimer le moteur fluidsynth :</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="2007"/>
        <source>Creating synthesizer engine</source>
        <translation>Création du moteur de synthèse</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="2011"/>
        <source>Failed to create the synthesizer.

Cannot continue without it.</source>
        <translation>Échec lors de la création du synthétiseur.

Ne peut pas continuer sans.</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="2042"/>
        <source>Loading soundfont: &quot;%1&quot; (bank offset %2)</source>
        <translation>Chargement de la banque de son : &quot;%1&quot; (décalage de banque %2)</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="2055"/>
        <source>Failed to set bank offset (%1) for soundfont: &quot;%2&quot;.</source>
        <translation>Échec d&apos;affectation du décalage de banque (%1) pour la banque de son : &quot;%2&quot;.</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="2065"/>
        <source>Creating audio driver (%1)</source>
        <translation>Création du pilote audio (%1)</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="2079"/>
        <source>Failed to create the audio driver (%1).

Cannot continue without it.</source>
        <translation>Échec de création du pilote audio (%1).

Ne peut pas continuer sans.</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="2092"/>
        <source>Creating MIDI router (%1)</source>
        <translation>Création du routeur MIDI (%1)</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="2101"/>
        <source>Failed to create the MIDI input router (%1).

No MIDI input will be available.</source>
        <translation>Échec de création du routeur MIDI (%1).

Aucune entrée MIDI ne sera disponible.</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="2109"/>
        <source>Creating MIDI driver (%1)</source>
        <translation>Création du pilote MIDI (%1)</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="2118"/>
        <source>Failed to create the MIDI driver (%1).

No MIDI input will be available.</source>
        <translation>Échec de création du pilote MIDI (%1).

Aucune entrée MIDI ne sera disponible.</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="1037"/>
        <source>Creating MIDI player</source>
        <translation>Création du lecteur MIDI</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="1041"/>
        <source>Failed to create the MIDI player.

Continuing without a player.</source>
        <translation>Échec de création du lecteur MIDI.

Continue sans le lecteur.</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="2127"/>
        <source>Creating server</source>
        <translation>Création du serveur</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="2161"/>
        <source>Failed to create the server.

Continuing without it.</source>
        <translation>Échec de création du serveur.

Continue sans.</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="2165"/>
        <source>Server mode disabled.

Continuing without it.</source>
        <translation>Mode serveur désactivé.

Continue sans.</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="2199"/>
        <source>Synthesizer engine started.</source>
        <translation>Moteur du synthétiseur démarré.</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="2242"/>
        <source>Destroying server</source>
        <translation>Destruction du serveur</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="2250"/>
        <source>Stopping MIDI player</source>
        <translation>Arrêt du lecteur MIDI</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="2252"/>
        <source>Waiting for MIDI player to terminate</source>
        <translation>Attends que le lecteur MIDI s&apos;arrête</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="1031"/>
        <location filename="../qsynthMainForm.cpp" line="2254"/>
        <source>Destroying MIDI player</source>
        <translation>Destruction du lecteur MIDI</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="2262"/>
        <source>Destroying MIDI driver</source>
        <translation>Destruction du pilote MIDI</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="2266"/>
        <source>Destroying MIDI router</source>
        <translation>Destruction du routeur MIDI</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="2273"/>
        <source>Destroying audio driver</source>
        <translation>Destruction du pilote audio</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="2296"/>
        <source>Unloading soundfont: &quot;%1&quot; (SFID=%2)</source>
        <translation>Chargement de la banque de son : &quot;%1&quot; (SFID=%2)</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="2300"/>
        <source>Failed to unload the soundfont: &quot;%1&quot;.</source>
        <translation>Échec du chargement de la banque de son : &quot;%1&quot;.</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="2307"/>
        <source>Destroying synthesizer engine</source>
        <translation>Destruction du moteur du synthétiseur</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="2311"/>
        <source>Synthesizer engine terminated.</source>
        <translation>Moteur du synthétiseur arrêté.</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="2359"/>
        <source>New settings will be effective after
restarting all fluidsynth engines.</source>
        <translation>Les nouveaux réglages ne seront effectifs qu&apos;après
le redémarrage de tous les moteurs de fluildsynth.</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="2361"/>
        <location filename="../qsynthMainForm.cpp" line="2392"/>
        <source>Please note that this operation may cause
temporary MIDI and Audio disruption.</source>
        <translation>Veuillez noter que cette opération peut causer
une interruption temporaire du MIDI et de l&apos;audio.</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="2363"/>
        <source>Do you want to restart all engines now?</source>
        <translation>Voulez-vous redémarrer tous les moteurs maintenant?</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="2389"/>
        <source>New settings will be effective after
restarting the fluidsynth engine:</source>
        <translation>Les nouveaux réglages ne seront effectifs qu&apos;après
le redémarrage du moteur fluidsynth :</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="2394"/>
        <source>Do you want to restart the engine now?</source>
        <translation>Voulez-vous redémarrer le moteur maintenant?</translation>
    </message>
</context>
<context>
    <name>qsynthMessagesForm</name>
    <message>
        <location filename="../qsynthMessagesForm.ui" line="33"/>
        <source>Messages</source>
        <translation>Messages</translation>
    </message>
    <message>
        <location filename="../qsynthMessagesForm.ui" line="48"/>
        <source>Messages output log</source>
        <translation>Sortie des messages de log</translation>
    </message>
    <message>
        <location filename="../qsynthMessagesForm.cpp" line="133"/>
        <source>Logging stopped --- %1 ---</source>
        <translation>Enregistrement arrêté --- %1 ---</translation>
    </message>
    <message>
        <location filename="../qsynthMessagesForm.cpp" line="143"/>
        <source>Logging started --- %1 ---</source>
        <translation>Enregistrement démarré --- %1 ---</translation>
    </message>
</context>
<context>
    <name>qsynthOptionsForm</name>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="461"/>
        <source>Display</source>
        <translation>Affichage</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="62"/>
        <source>Messages</source>
        <translation>Messages</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="50"/>
        <source>General</source>
        <translation>Général</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="89"/>
        <source>Sample messages text font display</source>
        <translation>Messages d&apos;exemple pour l&apos;affichage de la police</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="117"/>
        <source>Select font for the messages text display</source>
        <translation>Sélection de la police pour l&apos;affichage du texte des messages</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="120"/>
        <source>&amp;Font...</source>
        <translation>&amp;Police...</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="152"/>
        <source>Whether to keep a maximum number of lines in the messages window</source>
        <translation>Si on doit conserver un nombre maximum de lignes dans la fenêtre de messages</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="155"/>
        <source>&amp;Messages limit:</source>
        <translation>Limite de &amp;messages :</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="168"/>
        <source>The maximum number of message lines to keep in view</source>
        <translation>Le nombre maximum de lignes de message à conserver</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="178"/>
        <source>100</source>
        <translation>100</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="183"/>
        <source>250</source>
        <translation>250</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="188"/>
        <source>500</source>
        <translation>500</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="193"/>
        <source>1000</source>
        <translation>1000</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="198"/>
        <source>2500</source>
        <translation>2500</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="203"/>
        <source>5000</source>
        <translation>5000</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="220"/>
        <source>Logging</source>
        <translation>Connection</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="241"/>
        <source>Messages log file</source>
        <translation>Fichier d&apos;enregistrement des messages</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="272"/>
        <source>Browse for the messages log file location</source>
        <translation>Parcourir l&apos;emplacement des messages du fichiers log</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="275"/>
        <location filename="../qsynthOptionsForm.ui" line="694"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="288"/>
        <source>Whether to activate a messages logging to file.</source>
        <translation>Doit-on activer l&apos;enregistrement des messages dans un fichier.</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="291"/>
        <source>Messages &amp;log file:</source>
        <translation>F&amp;ichier d&apos;enregistrement des messages :</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="473"/>
        <source>Knobs</source>
        <translation>Boutons</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="488"/>
        <source>Kno&amp;b graphic style:</source>
        <translation>Style graphique des &amp;boutons :</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="504"/>
        <source>Graphic style for knobs</source>
        <translation>Style graphique pour les boutons</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="508"/>
        <source>Classic</source>
        <translation>Classique</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="513"/>
        <source>Vokimon</source>
        <translation>Vokimon</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="518"/>
        <source>Peppino</source>
        <translation>Peppino</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="523"/>
        <source>Skulpture</source>
        <translation>Skulpture</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="528"/>
        <location filename="../qsynthOptionsForm.ui" line="584"/>
        <source>Legacy</source>
        <translation>Legacy</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="558"/>
        <source>Mouse motion be&amp;havior:</source>
        <translation>Compor&amp;tement du déplacement de la souris :</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="577"/>
        <source>Mouse motion behavior for knobs</source>
        <translation>Comportement du déplacement de la souris pour les boutons</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="589"/>
        <source>Radial</source>
        <translation>Radiale</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="594"/>
        <source>Linear</source>
        <translation>Linéaire</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="611"/>
        <source>Custom</source>
        <translation>Personnalisé</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="626"/>
        <source>&amp;Color palette theme:</source>
        <translation>Thème de palette de &amp;couleur :</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="645"/>
        <source>Custom color palette theme</source>
        <translation>Theme de palette de couleur personnalisé</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="657"/>
        <source>Wonton Soup</source>
        <translatorcomment>DO NOT TRANSLATE</translatorcomment>
        <translation></translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="662"/>
        <source>KXStudio</source>
        <translatorcomment>DO NOT TRANSLATE</translatorcomment>
        <translation></translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="691"/>
        <source>Manage custom color palette themes</source>
        <translation>Gérer les thèmes de palette de couleur personnalisés</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="720"/>
        <source>&amp;Widget style theme:</source>
        <translation>Thème de style de &amp;widget :</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="736"/>
        <source>Custom widget style theme</source>
        <translation>Thème de style de widget personnalisé :</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="307"/>
        <source>Other</source>
        <translation>Autre</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="322"/>
        <source>Whether to ask for confirmation on application exit</source>
        <translation>Doit-on demander une confirmation lors de la fermeture de l&apos;application</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="325"/>
        <source>&amp;Confirm application close</source>
        <translation>&amp;Confirmer la fermeture de l&apos;application</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="415"/>
        <source>Whether to show system tray message on main window close</source>
        <translation>Si on doit afficher les messages de la barre d&apos;état lors de la fermeture de la fenêtre principale</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="418"/>
        <source>Sho&amp;w system tray message on close</source>
        <translation>Af&amp;ficher les messages de la barre d&apos;état à la fermeture</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="760"/>
        <source>Defaults</source>
        <translation>Défauts</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="338"/>
        <source>Whether to keep all child windows on top of the main window</source>
        <translation>Doit-on conserver toutes les sous-fenêtres au dessus de la fenêtre principale</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="34"/>
        <source>Options</source>
        <translation>Options</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="341"/>
        <source>&amp;Keep child windows always on top</source>
        <translation>Conserver les sous fenêtres &amp;toujours au dessus</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="354"/>
        <source>Whether to capture standard output (stdout/stderr) into messages window</source>
        <translation>Doit-on capturer la sortie standard (stdout/stderr) dans la fenêtre de messages</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="357"/>
        <source>Capture standard &amp;output</source>
        <translation>Capturer la s&amp;ortie standard</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="370"/>
        <source>Whether to monitor and show engine output peak level meters</source>
        <translation>Doit-on suivre et afficher le niveau de crête en sortie du moteur audio</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="373"/>
        <source>Output &amp;peak level meters</source>
        <translation>Afficher le niveau c&amp;rête de la sortie</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="399"/>
        <source>Whether to enable the system tray icon</source>
        <translation>Doit-on activer l&apos;icône de la barre d&apos;état</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="402"/>
        <source>&amp;Enable system tray icon</source>
        <translation>Activ&amp;er l&apos;icône de la barre d&apos;état</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="431"/>
        <source>Whether to start minimized to system tray</source>
        <translation>Doit-on démarrer minimisé dans la barre d&apos;état</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="434"/>
        <source>Start minimi&amp;zed to system tray</source>
        <translation>Démarrer minimi&amp;sé dans la barre d&apos;état</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="775"/>
        <source>Language</source>
        <translation>Langue</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="819"/>
        <source>&amp;Base font size:</source>
        <translation>Taille de police de &amp;base :</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="838"/>
        <source>Base application font size (pt.)</source>
        <translation>Taille de base de la police de l&apos;application (pt.)</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="652"/>
        <location filename="../qsynthOptionsForm.ui" line="743"/>
        <location filename="../qsynthOptionsForm.ui" line="792"/>
        <location filename="../qsynthOptionsForm.ui" line="845"/>
        <location filename="../qsynthOptionsForm.cpp" line="44"/>
        <source>(default)</source>
        <translation>(défaut)</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="850"/>
        <source>6</source>
        <translation>6</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="855"/>
        <source>7</source>
        <translation>7</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="860"/>
        <source>8</source>
        <translation>8</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="865"/>
        <source>9</source>
        <translation>9</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="870"/>
        <source>10</source>
        <translation>10</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="875"/>
        <source>11</source>
        <translation>11</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="880"/>
        <source>12</source>
        <translation>12</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.cpp" line="315"/>
        <source>Information</source>
        <translation>Informations</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.cpp" line="316"/>
        <source>Some settings may be only effective
next time you start this application.</source>
        <translation>Certains paramètres peuvent n&apos;être effectifs
qu&apos;après le prochain démarrage de cette application.</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.cpp" line="342"/>
        <source>Warning</source>
        <translation>Attention</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.cpp" line="343"/>
        <source>Some options have been changed.</source>
        <translation>Des options ont été modifiées.</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.cpp" line="344"/>
        <source>Do you want to apply the changes?</source>
        <translation>Voulez-vous appliquer les changements?</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.cpp" line="501"/>
        <source>Messages Log</source>
        <translation>Journal des messages</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.cpp" line="503"/>
        <source>Log files</source>
        <translation>Fichiers d&apos;enregistrement</translation>
    </message>
</context>
<context>
    <name>qsynthPaletteForm</name>
    <message>
        <location filename="../qsynthPaletteForm.ui" line="40"/>
        <source>Color Themes</source>
        <translation>Thèmes de couleur</translation>
    </message>
    <message>
        <location filename="../qsynthPaletteForm.ui" line="46"/>
        <source>Name</source>
        <translation>Nom</translation>
    </message>
    <message>
        <location filename="../qsynthPaletteForm.ui" line="64"/>
        <source>Current color palette name</source>
        <translation>Nom de la palette de couleur actuelle</translation>
    </message>
    <message>
        <location filename="../qsynthPaletteForm.ui" line="77"/>
        <source>Save current color palette name</source>
        <translation>Sauvegarder le nom de la palette de couleur actuelle</translation>
    </message>
    <message>
        <location filename="../qsynthPaletteForm.ui" line="80"/>
        <source>Save</source>
        <translation>Sauvegarder</translation>
    </message>
    <message>
        <location filename="../qsynthPaletteForm.ui" line="90"/>
        <source>Delete current color palette name</source>
        <translation>Effacer le nom de la palette de couleur actuelle</translation>
    </message>
    <message>
        <location filename="../qsynthPaletteForm.ui" line="93"/>
        <source>Delete</source>
        <translation>Effacer</translation>
    </message>
    <message>
        <location filename="../qsynthPaletteForm.ui" line="106"/>
        <source>Palette</source>
        <translation>Palette</translation>
    </message>
    <message>
        <location filename="../qsynthPaletteForm.ui" line="118"/>
        <source>Current color palette</source>
        <translation>Palette de couleur actuelle</translation>
    </message>
    <message>
        <location filename="../qsynthPaletteForm.ui" line="128"/>
        <source>Generate:</source>
        <translation>Générer :</translation>
    </message>
    <message>
        <location filename="../qsynthPaletteForm.ui" line="144"/>
        <source>Base color to generate palette</source>
        <translation>Couleur de base pour générer la palette</translation>
    </message>
    <message>
        <location filename="../qsynthPaletteForm.ui" line="151"/>
        <source>Reset all current palette colors</source>
        <translation>Réinitialiser toutes les couleurs de la palette actuelle</translation>
    </message>
    <message>
        <location filename="../qsynthPaletteForm.ui" line="154"/>
        <source> Reset</source>
        <translation> Réinitialiser</translation>
    </message>
    <message>
        <location filename="../qsynthPaletteForm.ui" line="177"/>
        <source>Import a custom color theme (palette) from file</source>
        <translation>Importer un thème (palette) de couleur personnalisé depuis un fichier</translation>
    </message>
    <message>
        <location filename="../qsynthPaletteForm.ui" line="180"/>
        <source>Import...</source>
        <translation>Importer...</translation>
    </message>
    <message>
        <location filename="../qsynthPaletteForm.ui" line="190"/>
        <source>Export a custom color theme (palette) to file</source>
        <translation>Exporter un thème (palette) de couleur personnalisé vers un fichier</translation>
    </message>
    <message>
        <location filename="../qsynthPaletteForm.ui" line="193"/>
        <source>Export...</source>
        <translation>Exporter...</translation>
    </message>
    <message>
        <location filename="../qsynthPaletteForm.ui" line="216"/>
        <source>Show Details</source>
        <translation>Afficher les détails</translation>
    </message>
    <message>
        <location filename="../qsynthPaletteForm.cpp" line="344"/>
        <source>Import File - %1</source>
        <translation>Importer le fichier - %1</translation>
    </message>
    <message>
        <location filename="../qsynthPaletteForm.cpp" line="260"/>
        <location filename="../qsynthPaletteForm.cpp" line="347"/>
        <location filename="../qsynthPaletteForm.cpp" line="392"/>
        <source>Palette files (*.%1)</source>
        <translation>Fichiers de palette (*.%1)</translation>
    </message>
    <message>
        <location filename="../qsynthPaletteForm.cpp" line="258"/>
        <source>Save Palette - %1</source>
        <translation>Sauvegarder la palette - %1</translation>
    </message>
    <message>
        <location filename="../qsynthPaletteForm.cpp" line="261"/>
        <location filename="../qsynthPaletteForm.cpp" line="348"/>
        <location filename="../qsynthPaletteForm.cpp" line="393"/>
        <source>All files (*.*)</source>
        <translation>Tous les fichiers (*.*)</translation>
    </message>
    <message>
        <location filename="../qsynthPaletteForm.cpp" line="379"/>
        <location filename="../qsynthPaletteForm.cpp" line="755"/>
        <location filename="../qsynthPaletteForm.cpp" line="763"/>
        <source>Warning - %1</source>
        <translation>Attention - %1</translation>
    </message>
    <message>
        <location filename="../qsynthPaletteForm.cpp" line="380"/>
        <source>Could not import from file:

%1

Sorry.</source>
        <translation>Impossible d&apos;importer depuis le fichier :

%1

Navré.</translation>
    </message>
    <message>
        <location filename="../qsynthPaletteForm.cpp" line="389"/>
        <source>Export File - %1</source>
        <translation>Exporter le fichier - %1</translation>
    </message>
    <message>
        <location filename="../qsynthPaletteForm.cpp" line="756"/>
        <source>Some settings have been changed.

Do you want to discard the changes?</source>
        <translation>Certains paramètres ont été modifié.

Souhaitez-vous abandonner les modifications ?</translation>
    </message>
    <message>
        <location filename="../qsynthPaletteForm.cpp" line="764"/>
        <source>Some settings have been changed:

&quot;%1&quot;.

Do you want to save the changes?</source>
        <translation>Certains paramètres ont été modifié.

&quot;%1&quot;.

Souhaitez-vous sauvegarder les modifications ?</translation>
    </message>
</context>
<context>
    <name>qsynthPaletteForm::PaletteModel</name>
    <message>
        <location filename="../qsynthPaletteForm.cpp" line="1007"/>
        <source>Color Role</source>
        <translation>Role de couleur</translation>
    </message>
    <message>
        <location filename="../qsynthPaletteForm.cpp" line="1010"/>
        <source>Active</source>
        <translation>Actif</translation>
    </message>
    <message>
        <location filename="../qsynthPaletteForm.cpp" line="1013"/>
        <source>Inactive</source>
        <translation>Inactif</translation>
    </message>
    <message>
        <location filename="../qsynthPaletteForm.cpp" line="1016"/>
        <source>Disabled</source>
        <translation>Désactivé</translation>
    </message>
</context>
<context>
    <name>qsynthPresetForm</name>
    <message>
        <location filename="../qsynthPresetForm.ui" line="33"/>
        <source>Channel Preset</source>
        <translation>Présélection de canal</translation>
    </message>
    <message>
        <location filename="../qsynthPresetForm.ui" line="65"/>
        <source>Preset</source>
        <translation>Pré-réglage</translation>
    </message>
    <message>
        <location filename="../qsynthPresetForm.ui" line="93"/>
        <source>Bank selector</source>
        <translation>Sélection de banque</translation>
    </message>
    <message>
        <location filename="../qsynthPresetForm.ui" line="118"/>
        <source>Bank</source>
        <translation>Banque</translation>
    </message>
    <message>
        <location filename="../qsynthPresetForm.ui" line="124"/>
        <source>Program selector</source>
        <translation>Sélection de programme</translation>
    </message>
    <message>
        <location filename="../qsynthPresetForm.ui" line="149"/>
        <source>Prog</source>
        <translation>Prog</translation>
    </message>
    <message>
        <location filename="../qsynthPresetForm.ui" line="154"/>
        <source>Name</source>
        <translation>Nom</translation>
    </message>
    <message>
        <location filename="../qsynthPresetForm.ui" line="159"/>
        <source>SFID</source>
        <translation>SFID</translation>
    </message>
    <message>
        <location filename="../qsynthPresetForm.ui" line="164"/>
        <source>Soundfont</source>
        <translation>Banque de son</translation>
    </message>
    <message>
        <location filename="../qsynthPresetForm.ui" line="173"/>
        <source>Whether to preview the current selection</source>
        <translation>Doit on générer un aperçu de la sélection courante</translation>
    </message>
    <message>
        <location filename="../qsynthPresetForm.ui" line="176"/>
        <source>Preview</source>
        <translation>Aperçu</translation>
    </message>
    <message>
        <location filename="../qsynthPresetForm.cpp" line="145"/>
        <source>Channel %1</source>
        <translation>Canal %1</translation>
    </message>
</context>
<context>
    <name>qsynthSetupForm</name>
    <message>
        <location filename="../qsynthSetupForm.ui" line="54"/>
        <source>Engine &amp;Name:</source>
        <translation>&amp;Nom du moteur :</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="67"/>
        <source>Engine display name</source>
        <translation>Nom d&apos;affichage du moteur</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="96"/>
        <source>&amp;MIDI</source>
        <translation>&amp;MIDI</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="366"/>
        <source>Whether to show MIDI router events on messages window</source>
        <translation>Si on doit afficher les évènements du routeur MIDI dans la fenêtre de messages</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="170"/>
        <location filename="../qsynthSetupForm.ui" line="725"/>
        <source>MIDI device name</source>
        <translation>Nom du pilote MIDI</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="102"/>
        <source>Enable MIDI input</source>
        <translation>Activer l&apos;entrée MIDI</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="105"/>
        <source>Enable MIDI &amp;Input</source>
        <translation>Activer l&apos;entrée M&amp;IDI</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="125"/>
        <source>Input MIDI driver</source>
        <translation>Pilote d&apos;entrée MIDI</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="356"/>
        <source>Print out verbose messages about MIDI events</source>
        <translation>Afficher des messages détaillés concernant les évènements MIDI</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="359"/>
        <source>&amp;Verbose MIDI event messages</source>
        <translation>Messages détaillés concernant les é&amp;vènements MIDI</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="183"/>
        <source>MIDI &amp;Channels:</source>
        <translation>&amp;Canaux MIDI :</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="202"/>
        <source>Number of MIDI channels</source>
        <translation>Nombre de canaux MIDI</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="231"/>
        <source>MIDI &amp;Bank Select mode:</source>
        <translation>Mode MIDI de sélection de &amp;banque :</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="244"/>
        <source>MIDI Bank Select mode</source>
        <translation>Mode MIDI de sélection de banque</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="251"/>
        <source>gm</source>
        <translation>gm</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="256"/>
        <source>gs</source>
        <translation>gs</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="261"/>
        <source>mma</source>
        <translation>mma</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="266"/>
        <source>xs</source>
        <translation>xs</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="311"/>
        <source>ALSA Sequencer client name identification</source>
        <translation>Nom d&apos;identifiant du client séquenceur ALSA</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="318"/>
        <source>pid</source>
        <translation>pid</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="323"/>
        <location filename="../qsynthSetupForm.ui" line="824"/>
        <source>qsynth</source>
        <translation>qsynth</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="377"/>
        <source>&amp;Audio</source>
        <translation>&amp;Audio</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="424"/>
        <source>Sample &amp;Format:</source>
        <translation>&amp;Format d&apos;échantillon :</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="414"/>
        <source>Output audio driver</source>
        <translation>Pilote de sortie audio</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="112"/>
        <source>MIDI &amp;Driver:</source>
        <translation>&amp;Pilote MIDI :</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="148"/>
        <source>MIDI D&amp;evice:</source>
        <translation>Périphériqu&amp;e MIDI :</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="298"/>
        <source>MIDI Client &amp;Name ID (ALSA/CoreMidi):</source>
        <translation>&amp;Nom du client MIDI ID (ALSA/CoreMidi) :</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="346"/>
        <source>Attempt to connect the MIDI inputs to the physical ports</source>
        <translation>Essaie de connecter les entrées MIDI aux ports physiques</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="349"/>
        <source>&amp;Auto Connect MIDI Inputs</source>
        <translation>&amp;Auto-connecte les entrées MIDI</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="369"/>
        <source>D&amp;ump MIDI router events</source>
        <translation>D&amp;umper les événements du routeur MIDI</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="401"/>
        <source>Audio &amp;Driver:</source>
        <translation>Pilote au&amp;dio :</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="437"/>
        <source>Sample format</source>
        <translation>Format d&apos;échantillon</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="514"/>
        <source>Period size in bytes (audio buffer size)</source>
        <translation>Taille de période en bytes (taille du tampon audio)</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="521"/>
        <location filename="../qsynthSetupForm.ui" line="609"/>
        <source>64</source>
        <translation>64</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="526"/>
        <source>128</source>
        <translation>128</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="531"/>
        <source>256</source>
        <translation>256</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="536"/>
        <source>512</source>
        <translation>512</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="541"/>
        <source>1024</source>
        <translation>1024</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="546"/>
        <source>2048</source>
        <translation>2048</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="551"/>
        <source>4096</source>
        <translation>4096</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="556"/>
        <source>8192</source>
        <translation>8192</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="564"/>
        <source>Buffer Cou&amp;nt:</source>
        <translation>&amp;Nombre de tampons :</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="463"/>
        <source>Sample rate in samples per second (Hz)</source>
        <translation>Fréquence d&apos;échantillonnage en échantillons par second (Hz)</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="473"/>
        <source>22050</source>
        <translation>22050</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="478"/>
        <source>44100</source>
        <translation>44100</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="483"/>
        <source>48000</source>
        <translation>48000</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="488"/>
        <source>88200</source>
        <translation>88200</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="493"/>
        <source>96000</source>
        <translation>96000</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="450"/>
        <source>Sample &amp;Rate:</source>
        <translation>F&amp;réquence d&apos;échantillonnage :</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="577"/>
        <source>Period count (number of audio buffers)</source>
        <translation>Nombre de période (nombre de tampons audio)</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="584"/>
        <source>2</source>
        <translation>2</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="589"/>
        <source>4</source>
        <translation>4</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="594"/>
        <source>8</source>
        <translation>8</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="599"/>
        <source>16</source>
        <translation>16</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="604"/>
        <source>32</source>
        <translation>32</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="501"/>
        <source>Buffer &amp;Size:</source>
        <translation>Dimen&amp;sion du tampon :</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="643"/>
        <source>Audio &amp;Channels:</source>
        <translation>&amp;Canaux audio :</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="665"/>
        <source>Number of audio groups</source>
        <translation>Nombre de groupes audio</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="684"/>
        <source>Number of enabled polyphonic voices</source>
        <translation>Nombre de voix polyphoniques activées</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="706"/>
        <source>Number of stereo audio channels</source>
        <translation>Nombre de canaux audio stéréos</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="738"/>
        <source>&amp;Polyphony:</source>
        <translation>&amp;Polyphonie :</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="770"/>
        <source>Audio &amp;Groups:</source>
        <translation>&amp;Groupes audio :</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="809"/>
        <source>JACK client name identification</source>
        <translation>Nom d&apos;identifiant du client JACK</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="819"/>
        <source>fluidsynth</source>
        <translation>fluidsynth</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="847"/>
        <source>Attempt to connect the JACK outputs to the physical ports</source>
        <translation>Tentative de connection des sorties JACK aux ports physiques</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="624"/>
        <source>Audio D&amp;evice:</source>
        <translation>Périphériqu&amp;e audio</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="796"/>
        <source>JACK Client &amp;Name ID:</source>
        <translation>&amp;Nom du client JACK ID</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="850"/>
        <source>&amp;Auto Connect JACK Outputs</source>
        <translation>&amp;Auto-connecte les sorties JACK</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="857"/>
        <source>Create multiple JACK output ports for channels, groups and effects</source>
        <translation>Crée de multiples ports de sortie JACK pour les canaux, groupes et effets</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="860"/>
        <source>&amp;Multiple JACK Outputs</source>
        <translation>Sorties JACK &amp;multiples</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="883"/>
        <source>&amp;WASAPI Exclusive Mode</source>
        <translation>Mode exclusif &amp;WASAPI</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="891"/>
        <source>&amp;Soundfonts</source>
        <translation>&amp;Banques de son</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="906"/>
        <source>Soundfont stack</source>
        <translation>Pile de banques de son</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="928"/>
        <source>SFID</source>
        <translation>SFID</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="933"/>
        <location filename="../qsynthSetupForm.ui" line="1075"/>
        <source>Name</source>
        <translation>Nom</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="938"/>
        <source>Offset</source>
        <translation>Décalage</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="951"/>
        <source>Open soundfont file for loading</source>
        <translation>Ouvre un fichier de banque de son pour lecture</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="954"/>
        <source>&amp;Open...</source>
        <translation>&amp;Ouvrir...</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="964"/>
        <source>Edit selected soundfont bank offset</source>
        <translation>Édite le décalage de banque de la banque de son sélectionnée</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="967"/>
        <source>&amp;Edit</source>
        <translation>Édit&amp;er</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="977"/>
        <source>Remove selected soundfont from stack</source>
        <translation>Supprime la banque de son sélectionnée de la pile</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="980"/>
        <source>&amp;Remove</source>
        <translation>Supp&amp;rimer</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="1003"/>
        <source>Move up selected soundfont towards the top of stack</source>
        <translation>Déplace la banque de son sélectionnée vers le haut de la pile</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="1006"/>
        <source>&amp;Up</source>
        <translation>Ha&amp;ut</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="1016"/>
        <source>Move down selected soundfont towards the bottom of stack</source>
        <translation>Déplace la banque de son sélectionnée vers le bas de la pile</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="1019"/>
        <source>&amp;Down</source>
        <translation>&amp;Bas</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="1032"/>
        <source>S&amp;ettings</source>
        <translation>Réglag&amp;es</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="1080"/>
        <source>Type</source>
        <translation>Type</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="1085"/>
        <source>Realtime</source>
        <translation>Temps réel</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="1090"/>
        <source>Current</source>
        <translation>Courant</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="1095"/>
        <source>Default</source>
        <translation>Défaut</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="1100"/>
        <source>Min</source>
        <translation>Min</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="1105"/>
        <source>Max</source>
        <translation>Max</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="1110"/>
        <source>Options</source>
        <translation>Options</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="34"/>
        <location filename="../qsynthSetupForm.cpp" line="405"/>
        <source>Setup</source>
        <translation>Réglage</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.cpp" line="637"/>
        <location filename="../qsynthSetupForm.cpp" line="921"/>
        <source>Warning</source>
        <translation>Attention</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.cpp" line="638"/>
        <source>Some settings have been changed.</source>
        <translation>Des réglages ont été changés.</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.cpp" line="639"/>
        <source>Do you want to apply the changes?</source>
        <translation>Voulez-vous appliquer les changements?</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.cpp" line="857"/>
        <source>Open...</source>
        <translation>Ouvrir...</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.cpp" line="862"/>
        <source>Edit</source>
        <translation>Éditer</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.cpp" line="867"/>
        <source>Remove</source>
        <translation>Supprimer</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.cpp" line="872"/>
        <source>Move Up</source>
        <translation>Déplace vers le Haut</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.cpp" line="876"/>
        <source>Move Down</source>
        <translation>Déplace vers le Bas</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.cpp" line="901"/>
        <location filename="../qsynthSetupForm.cpp" line="902"/>
        <source>Soundfont files</source>
        <translation>Fichiers de banque de son</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.cpp" line="903"/>
        <source>All files</source>
        <translation>Tous les fichiers</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.cpp" line="922"/>
        <source>Soundfont file already on list</source>
        <translation>Le fichier de banque de son est déjà dans la liste</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.cpp" line="924"/>
        <source>Add anyway?</source>
        <translation>Ajouter quand même?</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.cpp" line="951"/>
        <source>Error</source>
        <translation>Erreur</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.cpp" line="952"/>
        <source>Failed to add soundfont file</source>
        <translation>Impossible d&apos;ajouter le fichier de banque de son</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.cpp" line="954"/>
        <source>Please, check for a valid soundfont file.</source>
        <translation>Veuillez vérifier la validité du fichier de banque de son.</translation>
    </message>
</context>
</TS>
